@@ -9,8 +9,9 @@
 * @subpackage   MenuSet
 * @author    Andrew McMillan <andrew@mcmillan.net.nz>
 * @copyright Catalyst IT Ltd, Morphoss Ltd <http://www.morphoss.com/>
-* @license   http://gnu.org/copyleft/gpl.html GNU GPL v2
+* @license   http://gnu.org/copyleft/gpl.html GNU GPL v2 or later
 */
+
 require_once("AWLUtilities.php");
 
 /**
@@ -114,7 +115,7 @@ class MenuOption {
     $attribute_values = "";
     foreach( $this->attributes AS $k => $v ) {
       if ( substr($k, 0, 1) == '_' ) continue;
-      $attribute_values .= " $k=\"".htmlspecialchars($v)."\"";
+      $attribute_values .= ' '.$k.'="'.htmlspecialchars($v).'"';
     }
     $r = str_replace( '%%attributes%%', $attribute_values, $r );
 
@@ -192,7 +193,7 @@ function _CompareMenuSequence( $a, $b ) {
 *
 * A non-trivial example would look something like this:
 *<code>
-*require_once("MenuSet.php");
+*require("MenuSet.php");
 *$main_menu = new MenuSet('menu', 'menu', 'menu_active');
 *  ...
 *$other_menu = new MenuSet('submenu', 'submenu', 'submenu_active');
@@ -288,15 +289,16 @@ class MenuSet {
   * @param string $title Some tooltip help for the title tag.
   * @param string $active Whether this option should be marked as Active.
   * @param int $sortkey An (optional) value to allow option ordering.
+  * @param external open this link in a new window/tab.
   * @return mixed A reference to the MenuOption that was added, or false if none were added.
   */
-  function &AddOption( $label, $target, $title="", $active=false, $sortkey=null ) {
+  function &AddOption( $label, $target, $title="", $active=false, $sortkey=null, $external=false ) {
     if ( !isset($sortkey) ) {
       $sortkey = (isset($this->last_sortkey) ? $this->last_sortkey + 100 : 1000);
     }
     $this->last_sortkey = $sortkey;
     if ( version_compare(phpversion(), '5.0') < 0) {
-      $new_option =& new MenuOption( $label, $target, $title, $this->main_class, $sortkey );
+      $new_option = new MenuOption( $label, $target, $title, $this->main_class, $sortkey );
     }
     else {
       $new_option = new MenuOption( $label, $target, $title, $this->main_class, $sortkey );
@@ -320,6 +322,9 @@ class MenuSet {
       // If $active is a string, then we match the current URL to that as a Perl regex
       $new_option->Active( $this->active_class );
     }
+
+    if ( $external == true ) $new_option->Set('target', '_blank');
+
     return $new_option ;
   }
 
