@@ -80,14 +80,26 @@ class EditorField
     $this->Attributes[$k] = $v;
   }
 
+  function RenderLabel( $wrapme ) {
+    if ( !isset($this->Attributes['_label']) || !isset($this->Attributes['id'])) return $wrapme;
+    $class = (isset($this->Attributes['class']) ? $this->Attributes['class'] : 'entry');
+    $title = (isset($this->Attributes['title']) ? ' title="'.str_replace('"', '&#39;', $this->Attributes['title']) . '"' : '');
+    return( sprintf( '<label for="%s" class="%s"%s>%s %s</label>',
+             $this->Attributes['id'], $class, $title, $wrapme, $this->Attributes['_label']) );
+  }
+
   function RenderAttributes() {
     $attributes = "";
     if ( count($this->Attributes) == 0 ) return $attributes;
     foreach( $this->Attributes AS $k => $v ) {
-      $attributes .= " $k=\"" . str_replace('"', '\\"', $v) . '"';
+      if ( $k == '_label' ) continue;
+      $attributes .= " $k=\"" . str_replace('"', '&#39;', $v) . '"';
     }
     return $attributes;
   }
+
+  
+  
 }
 
 
@@ -160,15 +172,29 @@ class Editor
     }
   }
 
+  /**
+   * Gets the value of a field in the record currently assigned to this editor.
+   * @param string $value_field_name
+   */
   function Value( $value_field_name ) {
     if ( !isset($this->Record->{$value_field_name}) ) return null;
     return $this->Record->{$value_field_name};
   }
 
+  /**
+   * Assigns the value of a field in the record currently associated with this editor.
+   * @param string $value_field_name
+   * @param string $new_value
+   */
   function Assign( $value_field_name, $new_value ) {
+    if ( !isset($this->Record) ) $this->Record = (object) array();
     $this->Record->{$value_field_name} = $new_value;
   }
 
+  /**
+   * Sets or returns the form ID used for differentiating this form from others in the page.
+   * @param string $id
+   */
   function Id( $id = null ) {
     if ( isset($id) ) $this->Id = preg_replace( '#[^a-z0-9_+-]#', '', $id);
     return $this->Id;
@@ -276,6 +302,7 @@ class Editor
   */
   function Initialise( $values ) {
     $this->RecordAvailable = false;
+    if ( !isset($this->Record) ) $this->Record = (object) array();
     foreach( $values AS $fname => $value ) {
       $this->Record->{$fname} = $value;
     }
@@ -306,7 +333,7 @@ class Editor
     if ( $where == "" ) $where = $this->Where;
     $sql = sprintf( "SELECT %s FROM %s %s WHERE %s %s %s",
              $target_fields, $this->BaseTable, $this->Joins, $where, $this->Order, $this->Limit);
-    $this->Query = new PgQuery( $sql );
+    $this->Query = new AwlQuery( $sql );
     @dbg_error_log( 'editor', "DBG: EditorGetQry: %s", $sql );
     if ( $this->Query->Exec("Browse:$this->Title:DoQuery") ) {
       $this->Record = $this->Query->Fetch();
@@ -370,8 +397,8 @@ class Editor
         }
         else {
           @dbg_error_log( 'editor', "DBG: Current=%s, OptionQuery: %s", $currval, $field->LookupSql );
-          $opt_qry = new PgQuery( $field->LookupSql );
-          $option_list = $opt_qry->BuildOptionList($currval, "FieldOptions: $field_name" );
+          $opt_qry = new AwlQuery( $field->LookupSql );
+          $option_list = EntryField::BuildOptionList($opt_qry, $currval, "FieldOptions: $field_name" );
           $field->OptionList = $option_list;
         }
         return $option_list;
@@ -383,26 +410,31 @@ class Editor
           $option_list = $field->OptionList;
         }
         else {
-          @dbg_error_log( 'editor', "DBG: Current=%s, OptionQuery: %s", $currval, $field->LookupSql );
-          $opt_qry = new PgQuery( $field->LookupSql );
-          $option_list = $opt_qry->BuildOptionList($currval, "FieldOptions: $field_name" );
+          @dbg_error_log( 'editor', 'DBG: Current=%s, OptionQuery: %s', $currval, $field->LookupSql );
+          $opt_qry = new AwlQuery( $field->LookupSql );
+          $option_list = EntryField::BuildOptionList($opt_qry, $currval, 'FieldOptions: '.$field_name );
           $field->OptionList = $option_list;
         }
-        return "<select class=\"entry\" name=\"$field_name\"$attributes>$option_list</select>";
+        return '<select class="entry" name="'.$field_name.'"'.$attributes.'>'.$option_list.'</select>';
       case "checkbox":
-        switch ( $field_value ) {
-          case 'f':
-          case 'off':
-          case 'false':
-          case '':
-          case '0':
-            $checked = "";
-            break;
-
-          default:
-            $checked = " CHECKED";
+        if ( $field_value === true ) {
+          $checked = ' CHECKED';
         }
-        return "<input type=\"hidden\" value=\"off\" name=\"$field_name\"><input class=\"entry\" type=\"checkbox\" value=\"on\" name=\"$field_name\"$checked$attributes>";
+        else {
+          switch ( $field_value ) {
+            case 'f':
+            case 'off':
+            case 'false':
+            case '':
+            case '0':
+              $checked = "";
+              break;
+  
+            default:
+              $checked = ' CHECKED';
+          }
+        }
+        return $field->RenderLabel('<input type="hidden" value="off" name="'.$field_name.'"><input class="entry" type="checkbox" value="on" name="'.$field_name.'"'.$checked.$attributes.'>' );
       case "input":
         $size = (isset($part3) ? $part3 : 6);
         return "<input class=\"entry\" value=\"".htmlspecialchars($field_value)."\" name=\"$field_name\" size=\"$size\"$attributes>";
@@ -480,7 +512,7 @@ class Editor
       }
     }
     $this->Action = ( $is_update ? "update" : "create" );
-    $qry = new PgQuery( sql_from_post( $this->Action, $this->BaseTable, "WHERE ".$this->Where ) );
+    $qry = new AwlQuery( sql_from_post( $this->Action, $this->BaseTable, "WHERE ".$this->Where ) );
     if ( !$qry->Exec("Editor::Write") ) {
       $c->messages[] = "ERROR: $qry->errorstring";
       return 0;
