@@ -198,7 +198,9 @@ class iCalProp {
    * @return string The name for the property.
    */
   function TextMatch( $search ) {
-    if ( isset($this->content) ) return strstr( $this->content, $search );
+    if ( isset($this->content) ) {
+      return (stristr( $this->content, $search ) !== false);      
+    }
     return false;
   }
 
@@ -233,7 +235,7 @@ class iCalProp {
   function RenderParameters() {
     $rendered = "";
     foreach( $this->parameters AS $k => $v ) {
-      $escaped = preg_replace( "/([;:\"])/", '\\\\$1', $v);
+      $escaped = preg_replace( "/([;:])/", '\\\\$1', $v);
       $rendered .= sprintf( ";%s=%s", $k, $escaped );
     }
     return $rendered;
@@ -273,7 +275,7 @@ class iCalProp {
       default:
         $escaped = str_replace( '\\', '\\\\', $escaped);
         $escaped = preg_replace( '/\r?\n/', '\\n', $escaped);
-        $escaped = preg_replace( "/([,;\"])/", '\\\\$1', $escaped);
+        $escaped = preg_replace( "/([,;])/", '\\\\$1', $escaped);
     }
     $property = sprintf( "%s%s:", $this->name, $this->RenderParameters() );
     if ( (strlen($property) + strlen($escaped)) <= 72 ) {
@@ -632,7 +634,7 @@ class iCalComponent {
   * @return boolean true if we found 'em, false if we didn't.
   */
   function IsOrganizer( $email ) {
-    if ( !preg_match( '#^mailto:#', $email ) ) $email = 'mailto:$email';
+    if ( !preg_match( '#^mailto:#', $email ) ) $email = 'mailto:'.$email;
     $props = $this->GetPropertiesByPath('!VTIMEZONE/ORGANIZER');
     foreach( $props AS $k => $prop ) {
       if ( $prop->Value() == $email ) return true;
@@ -648,7 +650,7 @@ class iCalComponent {
   * @return boolean true if we found 'em, false if we didn't.
   */
   function IsAttendee( $email ) {
-    if ( !preg_match( '#^mailto:#', $email ) ) $email = 'mailto:$email';
+    if ( !preg_match( '#^mailto:#', $email ) ) $email = 'mailto:'.$email;
     if ( $this->IsOrganizer($email) ) return true; /** an organizer is an attendee, as far as we're concerned */
     $props = $this->GetPropertiesByPath('!VTIMEZONE/ATTENDEE');
     foreach( $props AS $k => $prop ) {
@@ -786,7 +788,7 @@ class iCalComponent {
   */
   function CloneConfidential() {
     $confidential = clone($this);
-    $keep_properties = array( 'DTSTAMP', 'DTSTART', 'RRULE', 'DURATION', 'DTEND', 'UID', 'CLASS', 'TRANSP' );
+    $keep_properties = array( 'DTSTAMP', 'DTSTART', 'RRULE', 'DURATION', 'DTEND', 'DUE', 'UID', 'CLASS', 'TRANSP', 'CREATED', 'LAST-MODIFIED' );
     $resource_components = array( 'VEVENT', 'VTODO', 'VJOURNAL' );
     $confidential->MaskComponents(array( 'VTIMEZONE', 'VEVENT', 'VTODO', 'VJOURNAL' ));
     $confidential->MaskProperties($keep_properties, $resource_components );
@@ -822,6 +824,7 @@ class iCalComponent {
     foreach( $this->components AS $v ) {   $rendered .= $v->Render();  }
     $rendered .= "END:$this->type\r\n";
 
+    $rendered = preg_replace('{(?<!\r)\n}', "\r\n", $rendered);
     if ( $unrestricted ) $this->rendered = $rendered;
 
     return $rendered;
@@ -888,19 +891,6 @@ class iCalComponent {
 ************************************************************************************
 */
 
-function deprecated( $method ) {
-  global $c;
-  if ( isset($c->dbg['ALL']) || isset($c->dbg['deprecated'])  || isset($c->dbg['icalendar']) ) {
-    $stack = debug_backtrace();
-    array_shift($stack);
-    if ( preg_match( '{/inc/iCalendar.php$}', $stack[0]['file'] ) && $stack[0]['line'] > __LINE__ ) return;
-    dbg_error_log("LOG", " iCalendar: Call to deprecated method '%s'", $method );
-    foreach( $stack AS $k => $v ) {
-      dbg_error_log( 'LOG', ' iCalendar: Deprecated call from line %4d of %s', $v['line'], $v['file']);
-    }
-  }
-}
-
 /**
 * A Class for handling Events on a calendar (DEPRECATED)
 *
@@ -1590,7 +1580,7 @@ class iCalendar {  // DEPRECATED
   function ApplyFilter( $filter, $value ) {
     deprecated('iCalendar::ApplyFilter' );
     foreach( $filter AS $k => $v ) {
-      $tag = $v->GetTag();
+      $tag = $v->GetNSTag();
       $value_type = gettype($value);
       $value_defined = (isset($value) && $value_type == 'string') || ($value_type == 'array' && count($value) > 0 );
       if ( $tag == 'urn:ietf:params:xml:ns:caldav:is-not-defined' && $value_defined ) {
@@ -1602,6 +1592,7 @@ class iCalendar {  // DEPRECATED
         return false;
       }
       else {
+        dbg_error_log( 'iCalendar', ":ApplyFilter: Have values for '%s' filter", $tag );
         switch( $tag ) {
           case 'urn:ietf:params:xml:ns:caldav:time-range':
             /** todo:: While this is unimplemented here at present, most time-range tests should occur at the SQL level. */
@@ -1610,11 +1601,11 @@ class iCalendar {  // DEPRECATED
             $search = $v->GetContent();
             // In this case $value will either be a string, or an array of iCalProp objects
             // since TEXT-MATCH does not apply to COMPONENT level - only property/parameter
-            if ( gettype($value) != 'string' ) {
-              if ( gettype($value) == 'array' ) {
+            if ( !is_string($value) ) {
+              if ( is_array($value) ) {
                 $match = false;
                 foreach( $value AS $k1 => $v1 ) {
-                  // $v1 could be an iCalProp object
+                  // $v1 MUST be an iCalProp object
                   if ( $match = $v1->TextMatch($search)) break;
                 }
               }
@@ -1624,13 +1615,12 @@ class iCalendar {  // DEPRECATED
               }
             }
             else {
-              $match = strstr( $value, $search[0] );
+              $match = (stristr( $value, $search ) !== false);      
             }
             $negate = $v->GetAttribute("negate-condition");
-            if ( isset($negate) && strtolower($negate) == "yes" && $match ) {
-              dbg_error_log( 'iCalendar', ":ApplyFilter: TEXT-MATCH of %s'%s' against '%s'", (isset($negate) && strtolower($negate) == "yes"?'!':''), $search, $value );
-              return false;
-            }
+            if ( isset($negate) && strtolower($negate) == "yes" ) $match = !$match;
+//            dbg_error_log( 'iCalendar', ":ApplyFilter: TEXT-MATCH returning %s", ($match?"yes":"no") );
+            return $match;
             break;
           case 'urn:ietf:params:xml:ns:caldav:comp-filter':
             $subfilter = $v->GetContent();
@@ -1666,8 +1656,10 @@ class iCalendar {  // DEPRECATED
   function TestFilter( $filters ) {
     deprecated('iCalendar::TestFilter' );
 
+//    dbg_error_log('iCalendar', ':TestFilter we have %d filters to test', count($filters) );
     foreach( $filters AS $k => $v ) {
-      $tag = $v->GetTag();
+      $tag = $v->GetNSTag();
+//      dbg_error_log('iCalendar', ':TestFilter working on tag "%s" %s"', $k, $tag );
       $name = $v->GetAttribute("name");
       $filter = $v->GetContent();
       if ( $tag == "urn:ietf:params:xml:ns:caldav:prop-filter" ) {
